<?php
require_once '../config/db.php';
date_default_timezone_set('America/Los_Angeles');

$weekStart = date('Y-m-d', strtotime('monday this week'));
$weekEnd   = date('Y-m-d', strtotime('sunday this week'));

// prevent duplicate snapshot
$stmt = $db->prepare("SELECT id FROM power_ranking_snapshots WHERE week_start = ?");
stmt->bind_param("s", $weekStart);
$stmt->execute();
$result = $stmt->get_result();
if ($result->num_rows > 0) {
    echo "Snapshot already exists.";
    exit;
}

// create new snapshot
$insert = $db->prepare("INSERT INTO power_ranking_snapshots (week_start, week_end) VALUES (?, ?)");
$end = date('Y-m-d', strtotime($start . ' +6 days'));
$insert->bind_param("ss", $start, $end);

$stmt->bind_param("s", $weekStart);
$stmt->execute();
$snapshotId = $stmt->insert_id;

// Load point legend
$legend = [];
$res = $db->query("SELECT match_type_id, win_points, loss_points, draw_points FROM power_point_legend");
while ($row = $res->fetch_assoc()) {
    $legend[$row['match_type_id']] = $row;
}

// Get team style IDs
$team_style_ids = [2, 3, 4]; // Tag Team, Trios, Stable

// Map config_id → style_id for each character
$configMap = [];
$res = $db->query("
    SELECT c.id, bc.style_id
      FROM characters c
      JOIN bio_configs bc ON c.config_id = bc.id
");
while ($row = $res->fetch_assoc()) {
    $configMap[$row['id']] = $row['style_id'];
}

// Map each team → its members
$teamMembers = [];
foreach (['tag_team_members'=>'tag_team_id','trios_members'=>'trios_id','stable_members'=>'stable_id'] as $table => $fk) {
    $res = $db->query("SELECT {$fk} AS team_id, member_id FROM {$table}");
    while ($r = $res->fetch_assoc()) {
        $teamMembers[$r['team_id']][] = $r['member_id'];
    }
}

// Calculate basic match‐result points
$matches = $db->query("
    SELECT em.id, em.match_type_id
      FROM event_matches em
      JOIN event_bookings eb ON em.booking_id = eb.id
     WHERE LOWER(eb.booking_status) = 'public'
       AND eb.air_date BETWEEN '{$weekStart}' AND '{$weekEnd}'
       AND em.is_segment = 0
");

$characterPoints = [];
while ($match = $matches->fetch_assoc()) {
    $matchId    = (int)$match['id'];
    $typeLegend = $legend[$match['match_type_id']] ?? ['win_points'=>0,'loss_points'=>0,'draw_points'=>0];

    $results = $db->query("SELECT character_id, result FROM match_results WHERE match_id = {$matchId}");
    while ($r = $results->fetch_assoc()) {
        $cid     = $r['character_id'];
        $outcome = strtolower($r['result']);
        $pts     = match($outcome) {
            'win'  => $typeLegend['win_points'],
            'loss' => $typeLegend['loss_points'],
            'nc'   => $typeLegend['draw_points'],
            default=> 0,
        };

        // team delegation
        $styleId = $configMap[$cid] ?? 0;
        if (in_array($styleId, $team_style_ids) && isset($teamMembers[$cid])) {
            foreach ($teamMembers[$cid] as $memberId) {
                $characterPoints[$memberId] = ($characterPoints[$memberId] ?? 0) + $pts;
            }
        } else {
            $characterPoints[$cid] = ($characterPoints[$cid] ?? 0) + $pts;
        }
    }
}

// Award bonuses
$awards = $db->query("
    SELECT cap.winner_id, ca.name
      FROM character_award_periods cap
      JOIN character_awards ca ON cap.award_id = ca.id
     WHERE cap.winner_id IS NOT NULL
       AND cap.start_date >= '{$weekStart}'
       AND cap.end_date   <= '{$weekEnd}'
");
while ($award = $awards->fetch_assoc()) {
    $pts = stripos($award['name'], 'week')  !== false ? 2
         : stripos($award['name'], 'month') !== false ? 5
         : stripos($award['name'], 'year')  !== false ? 10
         : 0;
    $characterPoints[$award['winner_id']] = ($characterPoints[$award['winner_id']] ?? 0) + $pts;
}

// Title reign changes
$reigns = $db->query("
    SELECT champion_before, champion_after
      FROM title_reigns
     WHERE change_date BETWEEN '{$weekStart}' AND '{$weekEnd}'
");
foreach ($reigns as $r) {
    if (!empty($r['champion_after'])) {
        $characterPoints[$r['champion_after']] = ($characterPoints[$r['champion_after']] ?? 0) + 2;
    }
    if (!empty($r['champion_before'])) {
        $characterPoints[$r['champion_before']] = ($characterPoints[$r['champion_before']] ?? 0) - 2;
    }
}

// Manual adjustments
$manuals = $db->query("
    SELECT character_id, SUM(points) AS pts
      FROM power_ranking_manual_adjustments
     WHERE week_start = '{$weekStart}'
     GROUP BY character_id
");
foreach ($manuals as $m) {
    $characterPoints[$m['character_id']] = ($characterPoints[$m['character_id']] ?? 0) + $m['pts'];
}

// ─── New: Segment‐Appearance Bonuses ────────────────────────────────────────
// +1 pt per segment appearance, capped at 5 pts per show
$segments = $db->query("
    SELECT
      sc.character_id,
      eb.id AS booking_id,
      COUNT(DISTINCT em.id) AS segment_count
    FROM segment_characters sc
    JOIN event_matches em   ON sc.match_id   = em.id
    JOIN event_bookings eb  ON em.booking_id = eb.id
    WHERE em.is_segment = 1
      AND LOWER(eb.booking_status) = 'public'
      AND eb.air_date BETWEEN '{$weekStart}' AND '{$weekEnd}'
    GROUP BY sc.character_id, eb.id
");
while ($row = $segments->fetch_assoc()) {
    $cid   = $row['character_id'];
    $count = (int)$row['segment_count'];
    $bonus = min($count, 5) * 1;
    $characterPoints[$cid] = ($characterPoints[$cid] ?? 0) + $bonus;
}

// ─── New: Interference Bonuses ─────────────────────────────────────────────
// +0.25 pt per interference, capped at 0.5 pts per show
$inters = $db->query("
    SELECT
      mi.character_id,
      eb.id AS booking_id,
      COUNT(DISTINCT mi.match_id) AS interference_count
    FROM match_interference mi
    JOIN event_matches em   ON mi.match_id   = em.id
    JOIN event_bookings eb  ON em.booking_id = eb.id
    WHERE em.is_segment = 0
      AND LOWER(eb.booking_status) = 'public'
      AND eb.air_date BETWEEN '{$weekStart}' AND '{$weekEnd}'
    GROUP BY mi.character_id, eb.id
");
while ($row = $inters->fetch_assoc()) {
    $cid   = $row['character_id'];
    $count = (int)$row['interference_count'];
    $bonus = min($count, 2) * 0.25;
    $characterPoints[$cid] = ($characterPoints[$cid] ?? 0) + $bonus;
}

// ────────────────────────────────────────────────────────────────────────────
foreach ($characterPoints as $charId => $points) {
    // enforce –5 floor
    $points = max($points, -5);

    // fetch last week's cumulative for movement
    $lastWeek = date('Y-m-d', strtotime('-7 days', strtotime($weekStart)));
    $prevStmt = $db->prepare("
        SELECT r.total_points
          FROM power_ranking_snapshots s
          JOIN power_ranking_scores   r ON s.id = r.snapshot_id
         WHERE s.week_start = ?
           AND r.character_id = ?
    ");
    $prevStmt->bind_param("si", $lastWeek, $charId);
    $prevStmt->execute();
    $prevRes = $prevStmt->get_result();
    $prevPts = $prevRes->fetch_assoc()['total_points'] ?? null;

    $movement = 'same';
    if ($prevPts !== null) {
        if ($points > $prevPts)   $movement = 'up';
        elseif ($points < $prevPts) $movement = 'down';
    }

    // insert final score
    $insert = $db->prepare("
        INSERT INTO power_ranking_scores
          (snapshot_id, character_id, total_points, movement)
        VALUES (?, ?, ?, ?)
    ");
    $insert->bind_param("iids", $snapshotId, $charId, $points, $movement);
    $insert->execute();
}

echo "Power rankings with team delegation and bonus points generated for {$weekStart}.";
