
<?php
require_once __DIR__ . '/../config/db.php';

// Get the latest 2 snapshots
$snapshotQuery = $db->query("SELECT id, week_start FROM power_ranking_snapshots ORDER BY id DESC LIMIT 2");
$snapshots = [];
while ($row = $snapshotQuery->fetch_assoc()) {
    $snapshots[] = $row;
}

if (count($snapshots) < 1) {
    echo "No snapshots available.";
    exit;
}

$currentSnapshotId = $snapshots[0]['id'];
$currentWeekStart = $snapshots[0]['week_start'];
$prevSnapshotId = $snapshots[1]['id'] ?? null;

// Get current week's points
$sqlCurrent = "
    SELECT c.id, c.name, c.alignment, c.gender, COALESCE(prs.total_points, 0) AS points
    FROM characters c
    LEFT JOIN power_ranking_scores prs ON prs.character_id = c.id AND prs.snapshot_id = ?
    WHERE c.deleted = 0 AND c.alumni = 0
";

$stmt = $db->prepare($sqlCurrent);
$stmt->bind_param('i', $currentSnapshotId);
$stmt->execute();
$result = $stmt->get_result();

$currentData = [];
while ($row = $result->fetch_assoc()) {
    $currentData[$row['id']] = $row;
    $currentData[$row['id']]['this_week'] = $row['points'];
    $currentData[$row['id']]['total'] = $row['points'];
}

// Add all historical points
$sqlTotal = "
    SELECT prs.character_id, SUM(prs.total_points) AS total_points
    FROM power_ranking_scores prs
    JOIN characters c ON c.id = prs.character_id
    WHERE c.deleted = 0 AND c.alumni = 0
    GROUP BY prs.character_id
";
$resTotal = $db->query($sqlTotal);
while ($row = $resTotal->fetch_assoc()) {
    $cid = $row['character_id'];
    if (!isset($currentData[$cid])) continue;
    $currentData[$cid]['total'] = (float)$row['total_points'];
}

// Add previous snapshot points
$prevPoints = [];
if ($prevSnapshotId) {
    $sqlPrev = "
        SELECT character_id, total_points
        FROM power_ranking_scores
        WHERE snapshot_id = ?
    ";
    $stmt = $db->prepare($sqlPrev);
    $stmt->bind_param('i', $prevSnapshotId);
    $stmt->execute();
    $resPrev = $stmt->get_result();
    while ($row = $resPrev->fetch_assoc()) {
        $prevPoints[$row['character_id']] = $row['total_points'];
    }
}

// Rank current total
usort($currentData, function($a, $b) {
    return $b['total'] <=> $a['total'];
});
$ranked = [];

// Sort and assign proper ranks with tie handling
usort($currentData, function($a, $b) {
    return $b['total'] <=> $a['total'];
});
$ranked = [];
$rank = 1;
$position = 1;
$last_points = null;
foreach ($currentData as $entry) {
    if ($last_points !== null && $entry['total'] != $last_points) {
        $rank = $position;
    }
    $entry['rank'] = $rank;
    $ranked[$entry['id']] = $entry;
    $last_points = $entry['total'];
    $position++;
}


// Determine movement
if ($prevSnapshotId) {
    // Get previous ranks
    $prevRankQuery = "
        SELECT prs.character_id, SUM(prs.total_points) AS total_points
        FROM power_ranking_scores prs
        JOIN characters c ON c.id = prs.character_id
        WHERE prs.snapshot_id <= ? AND c.deleted = 0 AND c.alumni = 0
        GROUP BY prs.character_id
    ";
    $stmt = $db->prepare($prevRankQuery);
    $stmt->bind_param('i', $prevSnapshotId);
    $stmt->execute();
    $res = $stmt->get_result();

    $prevRanks = [];
    while ($row = $res->fetch_assoc()) {
        $prevRanks[$row['character_id']] = $row['total_points'];
    }

    // Sort previous ranks
    arsort($prevRanks);
    $rankMap = [];
    $r = 1;
    foreach ($prevRanks as $cid => $pts) {
        $rankMap[$cid] = $r++;
    }

    foreach ($ranked as $cid => &$data) {
        $data['last_rank'] = $rankMap[$cid] ?? null;
        if ($data['last_rank'] === null) {
            $data['movement'] = 'NEW';
        } else {
            $diff = $data['last_rank'] - $data['rank'];
            if ($diff > 0) $data['movement'] = "▲ $diff";
            elseif ($diff < 0) $data['movement'] = "▼ " . abs($diff);
            else $data['movement'] = "＝";
        }
    }
}
?>

<!DOCTYPE html>
<html>
<head>
    <title>Power Ranking Summary</title>
    <link rel="stylesheet" href="css/admin.css">
</head>
<body>
<div class="dashboard-wrapper">
    <h2>Power Rankings – Week of <?= htmlspecialchars($currentWeekStart) ?></h2>
    <table class="table">
        <thead>
            <tr>
                <th>Rank</th>
                <th>Character</th>
                <th>Gender</th>
                <th>Alignment</th>
                <th>This Week</th>
                <th>Total</th>
                <th>Movement</th>
            </tr>
        </thead>
        <tbody>
        <?php foreach ($ranked as $char): 
        if ($char['movement'] === 'NEW' && floatval($char['total']) == 0.0) continue;
    ?>
            <tr>
                <td><?= $char['rank'] ?></td>
                <td><?= htmlspecialchars($char['name']) ?></td>
                <td><?= htmlspecialchars($char['gender']) ?></td>
                <td><?= htmlspecialchars($char['alignment']) ?></td>
                <td><?= number_format($char['this_week'], 2) ?></td>
                <td><?= number_format($char['total'], 2) ?></td>
                <td><?= $char['movement'] ?? '–' ?></td>
            </tr>
        <?php endforeach; ?>
        </tbody>
    </table>
</div>
</body>
</html>
