<?php
// admin/regenerate_power_rankings.php
// ------------------------------------------------------------------
// Enable error reporting for debugging
date_default_timezone_set('America/Los_Angeles');
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once __DIR__ . '/../config/db.php';
require_once __DIR__ . '/auth.php';
if (session_status() === PHP_SESSION_NONE) session_start();
requireLogin();

// Restrict to Admins (group_id>=9)
if (empty($_SESSION['user']['group_id']) || $_SESSION['user']['group_id'] < 9) {
    echo "<p>Unauthorized.</p>";
    exit;
}

// --- diagnostic view ---
if (!empty($_GET['diagnostic'])) {
    $weekStart = $_GET['week_start'] ?? date('Y-m-d', strtotime('monday this week'));
    $weekEnd   = date('Y-m-d', strtotime('sunday this week', strtotime($weekStart)));

    header('Content-Type: application/json');
    $output = [];

    // 1) match results diagnostic
    $sql = "SELECT em.id, em.is_segment, pm.match_type_id, mr.character_id, mr.result
            FROM event_matches em
            JOIN event_bookings eb ON em.booking_id=eb.id
            JOIN match_results mr ON mr.match_id=em.id
            JOIN power_point_legend pm ON em.match_type_id=pm.match_type_id
            WHERE eb.booking_status='Public' AND eb.is_deleted=0
              AND eb.air_date BETWEEN ? AND ?";
    $stmt = $db->prepare($sql);
    $stmt->bind_param('ss', $weekStart, $weekEnd);
    $stmt->execute();
    $rs = $stmt->get_result();
    while ($r = $rs->fetch_assoc()) {
        $output['match_results'][] = $r;
    }

    // 2) segments diagnostic
    $sql = "SELECT sc.character_id, em.id AS match_id
            FROM segment_characters sc
            JOIN event_matches em ON sc.match_id=em.id AND em.is_segment=1 AND em.is_deleted=0
            JOIN event_bookings eb ON em.booking_id=eb.id AND eb.booking_status='Public' AND eb.is_deleted=0 AND eb.air_date BETWEEN ? AND ?";
    $stmt = $db->prepare($sql);
    $stmt->bind_param('ss', $weekStart, $weekEnd);
    $stmt->execute();
    $rs = $stmt->get_result();
    while ($r = $rs->fetch_assoc()) {
        $output['segments'][] = $r;
    }

    // 3) snapshot scores diagnostic
    $sql = "SELECT s.week_start, r.character_id, r.total_points, r.movement
            FROM power_ranking_snapshots s
            JOIN power_ranking_scores r ON s.id=r.snapshot_id
            WHERE s.week_start BETWEEN DATE_SUB(?, INTERVAL 14 DAY) AND ?";
    $stmt = $db->prepare($sql);
    $stmt->bind_param('ss', $weekStart, $weekStart);
    $stmt->execute();
    $rs = $stmt->get_result();
    while ($r = $rs->fetch_assoc()) {
        $output['snapshot'][] = $r;
    }

    echo json_encode($output, JSON_PRETTY_PRINT);
    exit;
}

// --- rebuild interface ---
$year = isset($_GET['year']) ? (int)$_GET['year'] : (int)date('Y');
// build all Mondays of the year
$mondays = [];
$start = new DateTime("{$year}-01-01");
$end   = new DateTime("{$year}-12-31");
$end->modify('+1 day');
foreach (new DatePeriod($start, new DateInterval('P1D'), $end) as $d) {
    if ($d->format('N') === '1') {
        $mondays[] = $d->format('Y-m-d');
    }
}

$messages = [];
foreach ($mondays as $weekStart) {
    $weekEnd = date('Y-m-d', strtotime('sunday this week', strtotime($weekStart)));
    if ($weekEnd > date('Y-m-d')) continue;
    try {
        // clear old snapshot data
        $db->query("DELETE r FROM power_ranking_scores r JOIN power_ranking_snapshots s ON r.snapshot_id=s.id WHERE s.week_start='" . $db->real_escape_string($weekStart) . "'");
        $db->query("DELETE FROM power_ranking_snapshots WHERE week_start='" . $db->real_escape_string($weekStart) . "'");
        $messages[] = regenerateSnapshot($db, $weekStart, $weekEnd);
    } catch (Exception $e) {
        $messages[] = "Week {$weekStart} error: " . $e->getMessage();
    }
}

/**
 * Rebuild a single week's snapshot
 */
function regenerateSnapshot(mysqli $db, string $weekStart, string $weekEnd): string {
    // 1) insert snapshot record
    $stmt = $db->prepare("INSERT INTO power_ranking_snapshots (week_start) VALUES (?)");
    $stmt->bind_param('s', $weekStart);
    $stmt->execute();
    $snapshotId = $stmt->insert_id;

    // 2) load point legend
    $legend = [];
    $r = $db->query("SELECT match_type_id, win_points, loss_points, draw_points FROM power_point_legend");
    while ($row = $r->fetch_assoc()) {
        $legend[$row['match_type_id']] = $row;
    }

    // 3) load team/style mapping
    $teamStyleIds = [2,3,4];
    $configMap = [];
    $r = $db->query("SELECT c.id, bc.style_id FROM characters c JOIN bio_configs bc ON c.config_id=bc.id");
    while ($row = $r->fetch_assoc()) {
        $configMap[(int)$row['id']] = (int)$row['style_id'];
    }
    $teamMembers = [];
    foreach (['tag_team_members'=>'tag_team_id','trios_members'=>'trios_id','stable_members'=>'stable_id'] as $tbl=>$fk) {
        $q = $db->query("SELECT {$fk} AS t, member_id FROM {$tbl}");
        while ($m = $q->fetch_assoc()) {
            $teamMembers[(int)$m['t']][] = (int)$m['member_id'];
        }
    }

    $points = [];

    // 4) match results (non-segment)
    $q = $db->query(
        "SELECT em.id AS mid, em.match_type_id
         FROM event_matches em
         JOIN event_bookings eb ON em.booking_id=eb.id
         WHERE eb.booking_status='Public' AND eb.is_deleted=0
           AND eb.air_date BETWEEN '{$weekStart}' AND '{$weekEnd}'
           AND em.is_segment=0 AND em.is_deleted=0"
    );
    while ($m = $q->fetch_assoc()) {
        $mid = (int)$m['mid'];
        $leg = $legend[$m['match_type_id']] ?? ['win_points'=>0,'loss_points'=>0,'draw_points'=>0];
        $rr = $db->query("SELECT character_id, result FROM match_results WHERE match_id={$mid}");
        while ($res = $rr->fetch_assoc()) {
            $cid  = (int)$res['character_id'];
            switch (strtolower(trim($res['result']))) {
                case 'win':       $v = (float)$leg['win_points']; break;
                case 'draw': case 'nc': case 'no contest': $v = (float)$leg['draw_points']; break;
                case 'loss':      $v = -(float)$leg['loss_points']; break;
                default:          $v = 0;
            }
            if (in_array($configMap[$cid] ?? 0, $teamStyleIds) && isset($teamMembers[$cid])) {
                foreach ($teamMembers[$cid] as $mem) {
                    $points[$mem] = ($points[$mem] ?? 0) + $v;
                }
            } else {
                $points[$cid] = ($points[$cid] ?? 0) + $v;
            }
        }
    }

    // 5) segment bonuses (cap 5)
    $q = $db->query(
        "SELECT sc.character_id, COUNT(DISTINCT em.id) AS cnt
         FROM segment_characters sc
         JOIN event_matches em ON sc.match_id=em.id AND em.is_segment=1 AND em.is_deleted=0
         JOIN event_bookings eb ON em.booking_id=eb.id AND eb.booking_status='Public' AND eb.is_deleted=0 AND eb.air_date BETWEEN '{$weekStart}' AND '{$weekEnd}'
         GROUP BY sc.character_id"
    );
    while ($s = $q->fetch_assoc()) {
        $cid   = (int)$s['character_id'];
        $award = min((int)$s['cnt'], 5);
        $points[$cid] = ($points[$cid] ?? 0) + $award;
    }

    // 6) awards bonuses
    $q = $db->query("SELECT cap.winner_id, ca.name FROM character_award_periods cap JOIN character_awards ca ON cap.award_id=ca.id WHERE cap.winner_id IS NOT NULL AND cap.start_date>='{$weekStart}' AND cap.end_date<='{$weekEnd}'");
    while ($a = $q->fetch_assoc()) {
        $w = (int)$a['winner_id'];
        $b = stripos($a['name'],'week')!==false ? 2 : (stripos($a['name'],'month')!==false ? 5 : (stripos($a['name'],'year')!==false ? 10 : 0));
        $points[$w] = ($points[$w] ?? 0) + $b;
    }

    // 7) title reign changes
    $q = $db->query("SELECT champion_before, champion_after FROM title_reigns WHERE change_date BETWEEN '{$weekStart}' AND '{$weekEnd}'");
    while ($t = $q->fetch_assoc()) {
        if ($t['champion_after'])  $points[$t['champion_after']]  = ($points[$t['champion_after']]  ?? 0) + 2;
        if ($t['champion_before']) $points[$t['champion_before']] = ($points[$t['champion_before']] ?? 0) - 2;
    }

    // 8) manual adjustments
    $q = $db->query("SELECT character_id, SUM(points) AS pts FROM power_ranking_manual_adjustments WHERE week_start='{$weekStart}' GROUP BY character_id");
    while ($m = $q->fetch_assoc()) {
        $cid = (int)$m['character_id'];
        $points[$cid] = ($points[$cid] ?? 0) + (float)$m['pts'];
    }

    // 9) interference bonus (cap 2 * 0.25)
    $q = $db->query(
        "SELECT character_id, COUNT(DISTINCT match_id) AS ic
         FROM match_interference mi
         JOIN event_matches em ON mi.match_id=em.id
         JOIN event_bookings eb ON em.booking_id=eb.id
         WHERE eb.booking_status='Public' AND eb.is_deleted=0 AND eb.air_date BETWEEN '{$weekStart}' AND '{$weekEnd}'
         GROUP BY character_id"
    );
    while ($i = $q->fetch_assoc()) {
        $cid = (int)$i['character_id'];
        $c   = min((int)$i['ic'], 2);
        $points[$cid] = ($points[$cid] ?? 0) + ($c * 0.25);
    }

    // 10) save scores & movement
    foreach ($points as $cid => $pv) {
        $pv  = max($pv, -5);
        $pw  = date('Y-m-d', strtotime('-7 days', strtotime($weekStart)));
        $ps  = $db->prepare("SELECT r.total_points FROM power_ranking_snapshots s JOIN power_ranking_scores r ON s.id=r.snapshot_id WHERE s.week_start=? AND r.character_id=?");
        $ps->bind_param('si', $pw, $cid);
        $ps->execute();
        $old = $ps->get_result()->fetch_assoc()['total_points'] ?? null;
        $mv  = $old === null ? 'same' : ($pv > $old ? 'up' : ($pv < $old ? 'down' : 'same'));

        $iq = $db->prepare("INSERT INTO power_ranking_scores (snapshot_id,character_id,total_points,movement) VALUES (?,?,?,?)");
        $iq->bind_param('iids', $snapshotId, $cid, $pv, $mv);
        $iq->execute();
    }

    return "Week {$weekStart} rebuilt.";
}

// HTML output
?><!DOCTYPE html>
<html><head><meta charset="UTF-8"><title>Rebuild Power Rankings (<?php echo htmlspecialchars($year); ?>)</title>
<link rel="stylesheet" href="css/admin.css"></head><body>
<div class="dashboard-wrapper">
    <h1>Rebuild Power Rankings for Year <?php echo htmlspecialchars($year); ?></h1>
    <form method="get"><label for="year">Select Year:</label>
        <input type="number" name="year" id="year" value="<?php echo htmlspecialchars($year); ?>" min="2000" max="2100">
        <button type="submit">Rebuild</button>
    </form>
    <h2>Results:</h2><ul><?php foreach ($messages as $msg): ?><li><?php echo htmlspecialchars($msg); ?></li><?php endforeach; ?></ul>
</div>
</body></html>
