<?php
require_once __DIR__ . '/../config/db.php';

$latestSnapshot = $db
    ->query("SELECT id, week_start FROM power_ranking_snapshots ORDER BY week_start DESC LIMIT 1")
    ->fetch_assoc();

if (!$latestSnapshot) {
    echo "<div class='site-content'><div class='content-box'><h2>POWER RANKINGS</h2><p>No power rankings available.</p></div></div>";
    exit;
}

$snapshotId = $latestSnapshot['id'];
$weekStart = $latestSnapshot['week_start'];
$weekEnd = date('Y-m-d', strtotime($weekStart . ' +6 days'));


// Calculate year start based on this snapshot’s year
$yearStart = date('Y-01-01', strtotime($weekStart));

$stmt = $db->prepare("
    SELECT
      c.id,
      c.name,
      c.slug,
      SUM(
        CASE
          WHEN s.week_start >= ? AND s.week_start <= ?
          THEN prs.total_points ELSE 0
        END
      ) AS current_total,
      SUM(
        CASE
          WHEN s.week_start >= ? AND s.week_start < ?
          THEN prs.total_points ELSE 0
        END
      ) AS previous_total
    FROM power_ranking_scores prs
    JOIN power_ranking_snapshots s ON s.id = prs.snapshot_id
    JOIN characters c ON c.id = prs.character_id
    JOIN bio_configs bc ON c.config_id = bc.id
    JOIN bio_config_styles bcs ON bc.style_id = bcs.id
    WHERE bcs.name = 'Singles'
    GROUP BY c.id, c.name, c.slug
    ORDER BY current_total DESC
");
$stmt->bind_param("ssss", $yearStart, $weekStart, $yearStart, $weekStart);
$stmt->execute();
$result = $stmt->get_result();

$rankings = [];
while ($row = $result->fetch_assoc()) {
    // Derive movement
    $current = (float)$row['current_total'];
    $previous = (float)$row['previous_total'];
    if ($current > $previous) {
        $row['movement'] = 'up';
    } elseif ($current < $previous) {
        $row['movement'] = 'down';
    } else {
        $row['movement'] = 'same';
    }
    $row['total_points'] = $current;
    $rankings[] = $row;
}

// Fetch point‐value legend as before...
$legend = [];
$res = $db->query("
    SELECT m.name, p.win_points, p.loss_points, p.draw_points
    FROM power_point_legend p
    JOIN match_types m ON p.match_type_id = m.id
");
while ($r = $res->fetch_assoc()) {
    if ($r['win_points'] || $r['loss_points'] || $r['draw_points']) {
        $legend[] = $r;
    }
}

// Manual notes
$manualNotes = '';
$res = $db->query("SELECT notes FROM power_point_notes LIMIT 1");
if ($res && $res->num_rows) {
    $manualNotes = $res->fetch_assoc()['notes'] ?? '';
}

// Fixed bonuses array remains unchanged
$fixedBonuses = [
    "Appears in a segment on the show"  => "+1 point (Max 5 per show)",
    "Interferes in a match"             => "+0.25 points (Max 0.50 per show)",
    "Championship Win Bonus"            => "Normal Match Points +2",
    "Championship Loss Penalty"         => "Normal Match Points -2",
    "Successful Title Defense"          => "Normal Match Points +1",
    "PPV/PLE Win Bonus"                 => "+0.5",
    "PPV/PLE Loss Penalty"              => "-0.5",
    "PPV/PLE No Contest Bonus"          => "+0.2",
];
?>

<div class="site-content">
  <div class="content-box">
    <h2 class="chronology-title">POWER RANKINGS</h2>
    <p class="updated-date">As of <?= date('F j, Y', strtotime($weekEnd)) ?></p>

    <?php if (empty($rankings)): ?>
      <p>No rankings to show.</p>
    <?php else: ?>
      <table class="rankings-table">
        <thead>
          <tr>
            <th>Rank</th>
            <th>Character</th>
            <th>Points</th>
            <th>Movement</th>
          </tr>
        </thead>
        <tbody>
          <?php
          $rank = 1;
          foreach ($rankings as $entry):
            $mv     = $entry['movement'];
            $symbol = $mv === 'up' ? '▲' : ($mv === 'down' ? '▼' : '＝');
            $cls    = 'movement-' . $mv;
          ?>
          <tr>
            <td><?= $rank++ ?></td>
            <td>
              <a href="/character/<?= urlencode($entry['slug']) ?>">
                <?= htmlspecialchars($entry['name']) ?>
              </a>
            </td>
            <td><?= number_format($entry['total_points'], 2) ?></td>
            <td class="<?= $cls ?>"><?= $symbol ?></td>
          </tr>
          <?php endforeach; ?>
        </tbody>
      </table>
    <?php endif; ?>

    <div class="legend-box">
      <h4>Point Value Legend</h4>
      <ul class="legend-list">
        <?php foreach ($legend as $row): ?>
          <li>
            <strong><?= htmlspecialchars($row['name']) ?>:</strong>
            Win: <?= number_format($row['win_points'],1) ?>,
            Loss: <?= number_format($row['loss_points'],1) ?>,
            Draw/NC: <?= number_format($row['draw_points'],1) ?>
          </li>
        <?php endforeach; ?>
        <?php foreach ($fixedBonuses as $label => $value): ?>
          <li><strong><?= $label ?>:</strong> <?= $value ?></li>
        <?php endforeach; ?>
      </ul>
      <?php if ($manualNotes): ?>
        <div class="manual-notes"><?= $manualNotes ?></div>
      <?php endif; ?>
    </div>
  </div>
</div>
