<?php
// view-event-bookings.php (year/month filters + enhancements)
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once 'config/db.php';


$slug = $_GET['slug'] ?? '';
if (!$slug) die("<h2>No event specified.</h2>");

function getEventInfoBySlug($db, $slug) {
    $stmt = $db->prepare("SELECT id, name, image_path FROM events WHERE short_name = ? AND is_deleted = 0");
    $stmt->bind_param('s', $slug);
    $stmt->execute();
    return $stmt->get_result()->fetch_assoc();
}

function getAvailableYears($db, $eventId) {
    $stmt = $db->prepare("SELECT DISTINCT YEAR(air_date) as year FROM event_bookings WHERE event_id = ? AND is_deleted = 0 AND booking_status = 'Public' ORDER BY year DESC");
    $stmt->bind_param('i', $eventId);
    $stmt->execute();
    return $stmt->get_result()->fetch_all(MYSQLI_ASSOC);
}

function countFilteredBookings($db, $eventId, $year, $month) {
    $sql = "SELECT COUNT(*) FROM event_bookings WHERE event_id = ? AND is_deleted = 0 AND booking_status = 'Public'";
    $params = [$eventId];
    $types = 'i';

    if ($year) { $sql .= " AND YEAR(air_date) = ?"; $params[] = $year; $types .= 'i'; }
    if ($month) { $sql .= " AND MONTH(air_date) = ?"; $params[] = $month; $types .= 'i'; }

    $stmt = $db->prepare($sql);
    $stmt->bind_param($types, ...$params);
    $stmt->execute();
    $stmt->bind_result($count);
    $stmt->fetch();
    return $count;
}

function getFilteredBookings($db, $eventId, $year, $month, $limit, $offset) {
    $sql = "SELECT id, label, air_date, custom_image_path FROM event_bookings WHERE event_id = ? AND is_deleted = 0 AND booking_status = 'Public'";
    $params = [$eventId];
    $types = 'i';

    if ($year) { $sql .= " AND YEAR(air_date) = ?"; $params[] = $year; $types .= 'i'; }
    if ($month) { $sql .= " AND MONTH(air_date) = ?"; $params[] = $month; $types .= 'i'; }

    $sql .= " ORDER BY air_date DESC LIMIT ? OFFSET ?";
    $params[] = $limit;
    $params[] = $offset;
    $types .= 'ii';

    $stmt = $db->prepare($sql);
    $stmt->bind_param($types, ...$params);
    $stmt->execute();
    return $stmt->get_result()->fetch_all(MYSQLI_ASSOC);
}

$event = getEventInfoBySlug($db, $slug);
if (!$event) die("<h2>Event not found.</h2>");

$year = isset($_GET['year']) ? (int)$_GET['year'] : null;
$month = isset($_GET['month']) ? (int)$_GET['month'] : null;
$compact = isset($_GET['density']) && $_GET['density'] === 'compact';
$limit = $compact ? 24 : 12;
$page = max(1, (int)($_GET['p'] ?? 1));
$offset = ($page - 1) * $limit;

$availableYears = getAvailableYears($db, $event['id']);
$total = countFilteredBookings($db, $event['id'], $year, $month);
$totalPages = ceil($total / $limit);
$bookings = getFilteredBookings($db, $event['id'], $year, $month, $limit, $offset);
?>
<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <title><?= htmlspecialchars($event['name']) ?> - Bookings</title>
  <link rel="stylesheet" href="../css/newuta.css">
  <style>
    .booking-grid {
      display: flex;
      flex-wrap: wrap;
      gap: <?= $compact ? '10px' : '20px' ?>;
      justify-content: center;
      margin-top: 2rem;
    }
    .booking-card {
      position: relative;
      width: <?= $compact ? '160px' : '250px' ?>;
      border: 2px solid var(--bold-gold);
      border-radius: 8px;
      overflow: hidden;
      background-color: #2b2b2b;
      box-shadow: 0 0 6px rgba(0,0,0,0.4);
    }
    .booking-card img {
      width: 100%;
      height: auto;
      display: block;
    }
    .booking-card .air-date-overlay {
      position: absolute;
      bottom: 8px;
      right: 8px;
      background-color: rgba(0,0,0,0.75);
      color: gold;
      font-weight: bold;
      padding: 4px 6px;
      font-size: 0.85rem;
      border-radius: 4px;
    }
    .filter-bar, .density-toggle, .pagination {
      text-align: center;
      margin-top: 1rem;
    }
    .filter-bar select {
      padding: 5px 10px;
      margin: 0 5px;
      font-size: 1rem;
      background: #1f1f1f;
      color: #f5f5f5;
      border: 1px solid #444;
      border-radius: 4px;
    }
    .pagination a {
      color: gold;
      margin: 0 5px;
      text-decoration: none;
      font-weight: bold;
    }
    .pagination a.active {
      text-decoration: underline;
    }
  </style>
</head>
<body>
  <div class="site-content">
    <a href="/event-library" style="color: gold; text-decoration: none;">&larr; Back to Event Library</a>
    <h1 class="page-title"><?= htmlspecialchars($event['name']) ?> - Episodes</h1>

    <div class="filter-bar">
      <form method="GET">
        <input type="hidden" name="slug" value="<?= htmlspecialchars($slug) ?>">
        <input type="hidden" name="density" value="<?= $compact ? 'compact' : 'standard' ?>">
        <label for="year">Year:</label>
        <select name="year" id="year">
          <option value="">All</option>
          <?php foreach ($availableYears as $y): ?>
            <option value="<?= $y['year'] ?>"<?= ($year == $y['year']) ? ' selected' : '' ?>><?= $y['year'] ?></option>
          <?php endforeach; ?>
        </select>
        <label for="month">Month:</label>
        <select name="month" id="month">
          <option value="">All</option>
          <?php for ($m = 1; $m <= 12; $m++): ?>
            <option value="<?= $m ?>"<?= ($month == $m) ? ' selected' : '' ?>><?= date('F', mktime(0, 0, 0, $m, 10)) ?></option>
          <?php endfor; ?>
        </select>
        <button type="submit">Filter</button>
      </form>
    </div>

    <div class="density-toggle">
      <a href="?slug=<?= urlencode($slug) ?>&year=<?= $year ?>&month=<?= $month ?>&density=standard"<?= !$compact ? ' class="active"' : '' ?>>Standard View</a> |
      <a href="?slug=<?= urlencode($slug) ?>&year=<?= $year ?>&month=<?= $month ?>&density=compact"<?= $compact ? ' class="active"' : '' ?>>Compact View</a>
    </div>

    <div class="booking-grid">
      <?php foreach ($bookings as $booking): ?>
        <?php $img = $booking['custom_image_path'] ?: $event['image_path']; ?>
        <a href="/event/<?= $booking['id'] ?>" class="booking-card" title="<?= htmlspecialchars($event['name'] . ': ' . $booking['label']) ?>">
          <img loading="lazy" src="../uploads/show-logos/<?= htmlspecialchars($img) ?>" alt="<?= htmlspecialchars($booking['label']) ?>">
          <div class="air-date-overlay"><?= htmlspecialchars($booking['air_date']) ?></div>
        </a>
      <?php endforeach; ?>
    </div>

    <div class="pagination">
      <?php for ($i = 1; $i <= $totalPages; $i++): ?>
        <a href="?slug=<?= urlencode($slug) ?>&year=<?= $year ?>&month=<?= $month ?>&density=<?= $compact ? 'compact' : 'standard' ?>&p=<?= $i ?>" class="<?= $i === $page ? 'active' : '' ?>">[<?= $i ?>]</a>
      <?php endfor; ?>
    </div>
  </div>
</body>
</html>