<?php
// user_content/win-loss.php — Fully styled Win/Loss Viewer (no .site-content wrapper)

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once 'config/db.php';

function fetchCombinedStats($db, $styleId, $genderFilter) {
    $stmt = $db->prepare("
        SELECT c.id, c.name, c.slug, c.alumni,
               wr.auto_wins, wr.manual_wins,
               wr.auto_losses, wr.manual_losses,
               wr.auto_ncs, wr.manual_ncs,
               wr.auto_matches, wr.manual_matches,
               c.gender
          FROM win_loss_records wr
          JOIN characters c ON c.id = wr.character_id
          JOIN bio_configs bc ON c.config_id = bc.id
         WHERE c.deleted = 0
           AND bc.style_id = ?
           AND ( ? = 'All' OR c.gender = ? )
         ORDER BY c.alumni ASC, c.name ASC
    ");
    // Bind styleId, genderFilter (twice for the OR clause)
    $stmt->bind_param("iss", $styleId, $genderFilter, $genderFilter);
    $stmt->execute();
    $res = $stmt->get_result();

    $results = [
        'active' => [],
        'alumni' => []
    ];

    while ($row = $res->fetch_assoc()) {
        $wins    = (int)$row['auto_wins'] + (int)$row['manual_wins'];
        $losses  = (int)$row['auto_losses'] + (int)$row['manual_losses'];
        $ncs     = (int)$row['auto_ncs'] + (int)$row['manual_ncs'];
        $matches = (int)$row['auto_matches'] + (int)$row['manual_matches'];
        $winPct  = ($matches > 0) ? round(($wins / $matches) * 100, 1) : 0;
        $lossPct = ($matches > 0) ? round(($losses / $matches) * 100, 1) : 0;

        $entry = [
            'name'     => $row['name'],
            'slug'     => $row['slug'],
            'wins'     => $wins,
            'losses'   => $losses,
            'ncs'      => $ncs,
            'matches'  => $matches,
            'win_pct'  => $winPct,
            'loss_pct' => $lossPct,
            'alumni'   => (bool)$row['alumni'],
            'gender'   => $row['gender'] ?? 'Other'
        ];

        $key = $entry['alumni'] ? 'alumni' : 'active';
        $results[$key][] = $entry;
    }

    return $results;
}

$tabs = [
    1 => 'Singles',
    2 => 'Tag Team',
    3 => 'Trios',
    4 => 'Stable'
];
$currentStyle = isset($_GET['style']) ? (int)$_GET['style'] : 1;
$currentStyle = array_key_exists($currentStyle, $tabs) ? $currentStyle : 1;

$genderFilter = $_GET['gender'] ?? 'All';
$genderFilter = in_array($genderFilter, ['All','Male','Female','Non-Binary','Other'])
    ? $genderFilter
    : 'All';


// First, build a list of available genders for the selected style (before filtering)
$tmpStats = fetchCombinedStats($db, $currentStyle, 'All');
$availableGenders = [];
foreach (['active','alumni'] as $grp) {
    foreach ($tmpStats[$grp] as $char) {
        $availableGenders[$char['gender']] = true;
    }
}
$genderTabs = ['All','Male','Female','Non-Binary','Other'];

// Now fetch the stats filtered by both style and gender
$stats = fetchCombinedStats($db, $currentStyle, $genderFilter);
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Win/Loss Records</title>

    <!-- Inline CSS copied from roster.php for tab styling -->
    
</head>
<body>
    <div class="site-content">
      <div class="content-box">
        <h2 class="chronology-title">WIN/LOSS RECORDS</h2>

        <!-- Bio Config (Style) Tabs -->
        <div class="tabs">
          <ul class="tab-links">
            <?php foreach ($tabs as $id => $label): 
                $liClass = ($id === $currentStyle) ? ' class="active"' : '';
                // Preserve current gender filter in the URL
                $url = "?style={$id}&gender=" . urlencode($genderFilter);
                $safeLabel = htmlspecialchars($label);
            ?>
              <li<?= $liClass ?>><a href="<?= $url ?>"><?= $safeLabel ?></a></li>
            <?php endforeach; ?>
          </ul>
        </div>

        <!-- Gender Tabs (must appear under style tabs) -->
        <div class="gender-tabs">
          <ul>
            <?php foreach ($genderTabs as $g): 
                if ($g === 'All' || isset($availableGenders[$g])) {
                  $liClass = ($g === $genderFilter) ? ' class="active"' : '';
                  $url = "?style={$currentStyle}&gender=" . urlencode($g);
                  $safeG = htmlspecialchars($g);
            ?>
              <li<?= $liClass ?>><a href="<?= $url ?>"><?= $safeG ?></a></li>
            <?php 
                }
            endforeach; ?>
          </ul>
        </div>

        <!-- Tab Content (only the selected Style & Gender) -->
       <div class="tab-content">
      <?php foreach (['active'=>'Active Characters','alumni'=>'Alumni Characters'] as $group=>$title): ?>
        <?php if (empty($stats[$group])) continue; ?>

        <?php if ($group==='alumni'): ?>
          <details style="margin-top:1.5em;">
            <summary style="font-size:1.2em; cursor:pointer; font-weight:bold;">
              <?= htmlspecialchars($title) ?>
            </summary>
            <div style="padding:0.5em 0;">
        <?php else: ?>
          <h2 class="win-loss-title"><?= htmlspecialchars($title) ?></h2>
        <?php endif; ?>

        <table class="win-loss-table">
          <thead>
            <tr>
              <th>Character</th><th>Wins</th><th>Losses</th><th>No Contests</th>
              <th>Total Matches</th><th>Win %</th><th>Loss %</th>
            </tr>
          </thead>
          <tbody>
            <?php foreach ($stats[$group] as $char): ?>
            <tr>
              <td><a href="/character/<?=htmlspecialchars($char['slug'])?>" class="character-link"><?=htmlspecialchars($char['name'])?></a></td>
              <td><?=$char['wins']?></td>
              <td><?=$char['losses']?></td>
              <td><?=$char['ncs']?></td>
              <td><?=$char['matches']?></td>
              <td><?=$char['win_pct']?>%</td>
              <td><?=$char['loss_pct']?>%</td>
            </tr>
            <?php endforeach; ?>
          </tbody>
        </table>

        <?php if ($group==='alumni'): ?>
            </div>
          </details>
        <?php endif; ?>
      <?php endforeach; ?>
    </div>
  </div>
</div>
</body>
</html>
